@@ -26,6 +26,8 @@ using std::map;
 #include <string>
 using std::string;
 
+const char *aciI[]    = {"CGC", "CGG",        // C/CGC, AciI
+                         "GCG", "CCG"};
 const char *ageI[]    = {"CCGGT",             // A/CCGGT, AgeI
                          "ACCGG"};
 const char *aluI[]    = {"CT",                // AG/CT, AluI
@@ -34,10 +36,16 @@ const char *apeKI[]   = {"CAGC", "CTGC",      // G/CWGC, ApeKI; W=A or T
  			 "GTCG", "GACG"};
 const char *apoI[]    = {"AATTC", "AATTT",    // R/AATTY, ApoI  (also known as XapI)
                          "GAATT", "AAATT"};
+const char *aseI[]    = {"TAAT",              // AT/TAAT, AseI
+                         "ATTA"};
 const char *bamHI[]   = {"GATCC",             // G/GATCC, BamHI
 			 "GGATC"};
+const char *bfaI[]    = {"TAG",               // C/TAG, BfaI
+                         "CTA"};
 const char *bgIII[]   = {"GATCT",             // A/GATCT, BgIII
 			 "AGATC"};
+const char *bspDI[]   = {"CGAT",              // AT/CGAT, BspDI
+			 "ATCG"};
 const char *bstYI[]   = {"GATCC", "GATCT",    // R/GATCY, BstYI (also known as PsuI)
                          "GGATC", "AGATC"};
 const char *claI[]    = {"CGAT",              // AT/CGAT, ClaI
@@ -138,7 +146,11 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz["aluI"]    = aluI;    // AG/CT, AluI
     renz["ageI"]    = ageI;    // A/CCGGT, AgeI
     renz["rsaI"]    = rsaI;    // GT/AC, RsaI
-
+    renz["aciI"]    = aciI;    // C/CGC, AciI
+    renz["bfaI"]    = bfaI;    // C/TAG, BfaI
+    renz["aseI"]    = aseI;    // AT/TAAT, AseI
+    renz["bspDI"]   = bspDI;   // AT/CGAT, BspDI
+    
     renz_cnt["sbfI"]    = 1;
     renz_cnt["pstI"]    = 1;
     renz_cnt["notI"]    = 1;
@@ -175,6 +187,10 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz_cnt["aluI"]    = 1;
     renz_cnt["ageI"]    = 1;
     renz_cnt["rsaI"]    = 1;
+    renz_cnt["aciI"]    = 2;
+    renz_cnt["bfaI"]    = 1;
+    renz_cnt["aseI"]    = 1;
+    renz_cnt["bspDI"]   = 1;
 
     renz_len["sbfI"]    = 6;
     renz_len["pstI"]    = 5;
@@ -212,6 +228,10 @@ initialize_renz(map<string, const char **> &renz, map<string, int> &renz_cnt, ma
     renz_len["aluI"]    = 2;
     renz_len["ageI"]    = 5;
     renz_len["rsaI"]    = 2;
+    renz_len["aciI"]    = 3;
+    renz_len["bfaI"]    = 3;
+    renz_len["aseI"]    = 4;
+    renz_len["bspDI"]   = 4;
 }
 
 void 
